Enum git_branchless::opts::SnapshotSubcommand
source · pub enum SnapshotSubcommand {
Create,
Restore {
snapshot_oid: NonZeroOid,
},
}Expand description
snapshot subcommands.
Variants
Create
Create a new snapshot containing the working copy contents, and then
reset the working copy to the current HEAD commit.
On success, prints the snapshot commit hash to stdout.
Restore
Fields
snapshot_oid: NonZeroOidThe commit hash for the snapshot.
Restore the working copy contents from the provided snapshot.