Enum git_branchless::opts::TestSubcommand
source · pub enum TestSubcommand {
Run {
exec: Option<String>,
command: Option<String>,
revset: Revset,
resolve_revset_options: ResolveRevsetOptions,
verbosity: u8,
strategy: Option<TestExecutionStrategy>,
jobs: Option<usize>,
},
Show {
exec: Option<String>,
command: Option<String>,
revset: Revset,
resolve_revset_options: ResolveRevsetOptions,
verbosity: u8,
},
Clean {
revset: Revset,
resolve_revset_options: ResolveRevsetOptions,
},
}Expand description
test subcommands.
Variants
Run
Fields
command: Option<String>The test command alias for the command to execute on each commit. Set with
git config branchless.test.alias.<name> <command>.
revset: RevsetThe set of commits to test.
resolve_revset_options: ResolveRevsetOptionsOptions for resolving revset expressions.
verbosity: u8Show the test output as well.
strategy: Option<TestExecutionStrategy>How to execute the tests.
Run a given command on a set of commits and present the successes and failures.
Show
Fields
command: Option<String>The test command alias for the command to execute on each commit. Set with
git config branchless.test.alias.<name> <command>.
revset: RevsetThe set of commits to show the test output for.
resolve_revset_options: ResolveRevsetOptionsOptions for resolving revset expressions.
verbosity: u8Show the test output as well.
Show the results of a set of previous test runs.
Clean
Fields
revset: RevsetThe set of commits whose results should be cleaned.
resolve_revset_options: ResolveRevsetOptionsOptions for resolving revset expressions.
Clean any cached test results.