pub struct SwitchOptions {
    pub interactive: bool,
    pub branch_name: Option<String>,
    pub force: bool,
    pub merge: bool,
    pub target: Option<String>,
}
Options for checking out a commit.

Fields

interactive: bool

Interactively select a commit to check out.

branch_name: Option<String>

When checking out the target commit, also create a branch with the provided name pointing to that commit.

force: bool

Forcibly switch commits, discarding any working copy changes if necessary.

merge: bool

If the current working copy changes do not apply cleanly to the target commit, start merge conflict resolution instead of aborting.

target: Option<String>

The commit or branch to check out.

If this is not provided, then interactive commit selection starts as if --interactive were passed.

If this is provided and the --interactive flag is passed, this text is used to pre-fill the interactive commit selector.