Struct git_branchless::opts::MoveOptions
source · pub struct MoveOptions {
pub force_rewrite_public_commits: bool,
pub force_in_memory: bool,
pub force_on_disk: bool,
pub detect_duplicate_commits_via_patch_id: bool,
pub resolve_merge_conflicts: bool,
pub dump_rebase_constraints: bool,
pub dump_rebase_plan: bool,
}Expand description
Options for moving commits.
Fields
force_rewrite_public_commits: boolForce moving public commits, even though other people may have access to those commits.
force_in_memory: boolOnly attempt to perform an in-memory rebase. If it fails, do not attempt an on-disk rebase.
force_on_disk: boolSkip attempting to use an in-memory rebase, and try an on-disk rebase directly.
detect_duplicate_commits_via_patch_id: boolDon’t attempt to deduplicate commits. Normally, a commit with the same contents as another commit which has already been applied to the target branch is skipped. If set, this flag skips that check.
resolve_merge_conflicts: boolAttempt to resolve merge conflicts, if any. If a merge conflict occurs and this option is not set, the operation is aborted.
dump_rebase_constraints: boolDebugging option. Print the constraints used to create the rebase plan before executing it.
dump_rebase_plan: boolDebugging option. Print the rebase plan that will be executed before executing it.